<?php
class NamasteCredHook extends myCRED_Hook {
	function __construct( $hook_prefs ) {
		global $wpdb;
		
		// select all courses
		$courses = $wpdb->get_results("SELECT ID, post_title FROM {$wpdb->posts} 
			WHERE post_type='namaste_course'  AND (post_status='publish' OR post_status='draft') ORDER BY post_title");
		
		// namaste prefs	
		$prefs = array();
		foreach($courses as $course) {
			$prefs['creds' . $course->ID] = 0;			
			$prefs['log' . $course->ID] = sprintf(__('%s for completing course %s', 'namastecred'), '%plural%', stripslashes($course->post_title));
		}
		
		$prefs['creds_any'] = 0;			
		$prefs['log_any'] = sprintf(__('%s for completing any course', 'namastecred'), '%plural%');
		
		parent::__construct( array(
			'id'       => 'completed_namaste_course',
			'defaults' => $prefs
		), $hook_prefs );
	}
	
	/**
	 * Hook into WordPress
	 */
	public function run() {
		add_action( 'namaste_completed_course',  array( $this, 'completed_course' ) , 10, 2);		
	}
	
	/**
	 * Check if the user qualifies for points
	 */
	public function completed_course( $student_id, $course_id ) {		
		global $wpdb, $user_ID;
		// Check if user is excluded (required)
		if ( $this->core->exclude_user( $user_ID ) ) return;
				
		// check the points from prefs, if 0 return
		$prefs = $this->prefs;
		if(empty($prefs['creds'.$course_id]) and empty($prefs['creds_any'])) return false;
		
		if(!empty($prefs['creds_any'])) {
			$this->core->add_creds(
				'completed_namaste_course_any',
				$student_id,
				$this->prefs['creds_any'],			
				$this->prefs['log_any']
			);
		}		
		
		// Make sure this is a unique event
		$hook_key = 'completed_namaste_course_'.$course_id;
		if ( $this->has_entry( $hook_key, '', $student_id ) ) return;

		// Execute
		if(!empty($prefs['creds'.$course_id])) {
			$this->core->add_creds(
				$hook_key,
				$student_id,
				$this->prefs['creds' . $course_id],			
				$this->prefs['log' . $course_id]
			);
		}		
	}
	
	/**
	 * Add Settings
	 */
	 public function preferences() {
	 	global $wpdb;
		// Our settings are available under $this->prefs
		$prefs = $this->prefs;
		// select all quiz categories
		$courses = $wpdb->get_results("SELECT ID, post_title FROM {$wpdb->posts} 
			WHERE post_type='namaste_course'  AND (post_status='publish' OR post_status='draft') ORDER BY post_title");
		
		foreach($courses as $course):?>
		
		<h2><?php printf(__('Course %s', 'namastecred'), stripslashes($course->post_title))?></h2>
		<p>&nbsp;</p>
	
		<!-- Set the amount -->
		<label class="subheader"><?php echo $this->core->plural(); ?></label>
		<ol>
			<li>
				<div class="h2"><input type="text" name="<?php echo $this->field_name( 'creds' . $course->ID ); ?>" id="<?php echo $this->field_id( 'creds' . $course->ID ); ?>" value="<?php echo esc_attr( @$prefs['creds'.$course->ID] ); ?>" size="8" /></div>
			</li>
		</ol>
			
		<!-- Then the log template -->
		<label class="subheader"><?php _e( 'Log template', 'mycred' ); ?></label>
		<ol>
			<li>
				<div class="h2"><input type="text" name="<?php echo $this->field_name( 'log' . $course->ID); ?>" id="<?php echo $this->field_id( 'log' . $course->ID); ?>" value="<?php echo (empty($prefs['log' . $course->ID]) ? sprintf(__('%s  completing course %s', 'namastecred'), '%plural% for ', stripslashes($course->post_title)) : $prefs['log' . $course->ID]); ?>" class="long" /></div>
			</li>
		</ol>
		<?php endforeach;?>
		
		<h2><?php _e('Any course', 'namastecred');?></h2>
		<p>&nbsp;</p>
	
		<!-- Set the amount -->
		<label class="subheader"><?php echo $this->core->plural(); ?></label>
		<ol>
			<li>
				<div class="h2"><input type="text" name="<?php echo $this->field_name( 'creds_any' ); ?>" id="<?php echo $this->field_id( 'creds_any' ); ?>" value="<?php echo esc_attr( @$prefs['creds_any'] ); ?>" size="8" /></div>
			</li>
		</ol>
			
		<!-- Then the log template -->
		<label class="subheader"><?php _e( 'Log template', 'mycred' ); ?></label>
		<ol>
			<li>
				<div class="h2"><input type="text" name="<?php echo $this->field_name( 'log_any'); ?>" id="<?php echo $this->field_id( 'log_any'); ?>" value="<?php echo (empty($prefs['log_any'])) ? sprintf(__('%s  completing any course', 'namastecred'), '%plural% for ') : $prefs['log_any']; ?>" class="long" /></div>
			</li>
		</ol>
<?php
	}

	/**
	 * Sanitize Preferences
	 */
	public function sanitise_preferences( $data ) {
		global $wpdb;
		$new_data = $data;
		
		// select all courses
		$courses = $wpdb->get_results("SELECT ID, post_title FROM {$wpdb->posts} 
		WHERE post_type='namaste_course'  AND (post_status='publish' OR post_status='draft') ORDER BY post_title");
		
		foreach($courses as $course) {
			$new_data['creds' . $course->ID] = ( !empty( $data['creds' . $course->ID] ) ) ? $data['creds' . $course->ID] : $this->defaults['creds' . $course->ID];
			$new_data['log' . $course->ID] = ( !empty( $data['log' . $course->ID] ) ) ? sanitize_text_field( $data['log' . $course->ID] ) : $this->defaults['log' . $course->ID];
		}
		
		$new_data['creds_any'] = ( !empty( $data['creds_any'] ) ) ? $data['creds_any'] : $this->defaults['creds_any'];
		$new_data['log_any'] = ( !empty( $data['log_any'] ) ) ? sanitize_text_field( $data['log_any'] ) : $this->defaults['log_any'];
		
		return $new_data;
	}
	
}